@@ -1242,6 +1242,19 @@ typedef struct {
   raptor_term* term;
 } raptor_abbrev_node;
 
+#ifdef RAPTOR_DEBUG
+#define RAPTOR_DEBUG_ABBREV_NODE(label, node) \
+  do {                                                       \
+    RAPTOR_DEBUG1(label " ");                                \
+    raptor_term_print_as_ntriples(node->term, stderr);       \
+    fprintf(stderr, " (refcount %d subject %d object %d)\n", \
+            node->ref_count,                                 \
+            node->count_as_subject,                          \
+            node->count_as_object);                          \
+  } while(0)
+#else
+#define RAPTOR_DEBUG_ABBREV_NODE(label, node)
+#endif
 
 typedef struct {
   raptor_abbrev_node* node;      /* node representing the subject of
@@ -1328,9 +1341,10 @@ int raptor_json_writer_newline(raptor_json_writer* json_writer);
 int raptor_json_writer_key_value(raptor_json_writer* json_writer, const char* key, size_t key_len, const char* value, size_t value_len);
 int raptor_json_writer_start_block(raptor_json_writer* json_writer, char c);
 int raptor_json_writer_end_block(raptor_json_writer* json_writer, char c);
-int raptor_json_writer_literal_object(raptor_json_writer* json_writer, unsigned char* s, unsigned char* lang, raptor_uri* datatype, const char* key, const char* type_key);
-int raptor_json_writer_blank_object(raptor_json_writer* json_writer, const unsigned char* blank);
+int raptor_json_writer_literal_object(raptor_json_writer* json_writer, unsigned char* s, size_t s_len, unsigned char* lang, raptor_uri* datatype);
+int raptor_json_writer_blank_object(raptor_json_writer* json_writer, const unsigned char* blank, size_t blank_len);
 int raptor_json_writer_uri_object(raptor_json_writer* json_writer, raptor_uri* uri);
+int raptor_json_writer_term(raptor_json_writer* json_writer, raptor_term *term);
 int raptor_json_writer_key_uri_value(raptor_json_writer* json_writer, const char* key, size_t key_len, raptor_uri* uri);
 
 /* raptor_memstr.c */
