@@ -27,11 +27,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -320,7 +315,7 @@ raptor_qname_copy(raptor_qname *qname)
 
     new_value = RAPTOR_MALLOC(unsigned char*, value_length + 1);
     if(!new_value) {
-      RAPTOR_FREE(raptor_qname, qname);
+      RAPTOR_FREE(raptor_qname, new_qname);
       return NULL;
     } 
 
@@ -453,11 +448,12 @@ raptor_qname_string_to_uri(raptor_namespace_stack *nstack,
     if(*name == ':') {
       name++;
       name_len--;
+      p = name + name_len;
+    } else {
+      for(p = name; *p && *p != ':'; p++)
+        ;
     }
     
-    for(p = name; *p && *p != ':'; p++)
-      ;
-    
     /* If ends with :, it is the URI of a namespace */
     if(RAPTOR_GOOD_CAST(size_t, p-name) == (name_len - 1)) {
       ns = raptor_namespaces_find_namespace(nstack, name,
@@ -538,7 +534,7 @@ raptor_qname_write(raptor_qname *qname, raptor_iostream* iostr)
  * 
  * Get the string form of a QName name
  * 
- * Return value: string or NULL on failure
+ * Return value: new string name or NULL on failure
  **/
 unsigned char*
 raptor_qname_to_counted_name(raptor_qname *qname, size_t* length_p)
@@ -630,3 +626,68 @@ raptor_qname_get_counted_value(raptor_qname* name, size_t* length_p)
     *length_p=name->value_length;
   return name->value;
 }
+
+
+/**
+ * raptor_qname_format_as_xml:
+ * @qname: qname object
+ * @length_p: pointer to length (or NULL)
+ *
+ * Format a qname in an XML style into a newly allocated string.
+ *
+ * Generates a string of the form a:b="value" or a="value"
+ * depending on the qname's prefix.  Double quotes are always used.
+ *
+ * If @length_p is not NULL, the length of the string is
+ * stored in the address it points to.
+ *
+ * Return value: qname formatted as newly allocated string or NULL on failure
+ **/
+unsigned char*
+raptor_qname_format_as_xml(const raptor_qname *qname, size_t *length_p)
+{
+  size_t length;
+  unsigned char *buffer;
+  const char quote='"';
+  unsigned char *p;
+
+  length = qname->local_name_length + 3 /* ="" */;
+  if(qname->value_length)
+    length += raptor_xml_escape_string(qname->world,
+                                       qname->value, qname->value_length,
+                                       NULL, 0, quote);
+
+  if(qname->nspace && qname->nspace->prefix_length > 0)
+    length += qname->nspace->prefix_length + 1; /* for : */
+
+  if(length_p)
+    *length_p = length;
+
+  buffer = RAPTOR_MALLOC(unsigned char*, length + 1);
+  if(!buffer)
+    return NULL;
+
+  p = buffer;
+
+  if(qname->nspace && qname->nspace->prefix_length > 0) {
+    memcpy(p, qname->nspace->prefix, qname->nspace->prefix_length);
+    p += qname->nspace->prefix_length;
+    *p++ = ':';
+  }
+  memcpy(p, qname->local_name, qname->local_name_length);
+  p += qname->local_name_length;
+  *p++ = '=';
+  *p++ = quote;
+  if(qname->value_length) {
+    p += raptor_xml_escape_string(qname->world,
+                                  qname->value, qname->value_length,
+                                  p, length, quote);
+  }
+  *p++ = quote;
+  /* *p used here since we never need to use value of p again [CLANG] */
+  *p = '\0';
+
+  return buffer;
+}
+
+
