@@ -26,10 +26,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -245,10 +241,19 @@ raptor_rss_parse_start(raptor_parser *rdf_parser)
   for(n = 0; n < RAPTOR_RSS_NAMESPACES_SIZE; n++)
     rss_parser->nspaces_seen[n] = 'N';
 
-  /* Optionally forbid network requests in the XML parser */
+  /* Optionally forbid internal network and file requests in the XML parser */
   raptor_sax2_set_option(rss_parser->sax2, 
                          RAPTOR_OPTION_NO_NET, NULL,
                          RAPTOR_OPTIONS_GET_NUMERIC(rdf_parser, RAPTOR_OPTION_NO_NET));
+  raptor_sax2_set_option(rss_parser->sax2, 
+                         RAPTOR_OPTION_NO_FILE, NULL,
+                         RAPTOR_OPTIONS_GET_NUMERIC(rdf_parser, RAPTOR_OPTION_NO_FILE));
+  raptor_sax2_set_option(rss_parser->sax2, 
+                         RAPTOR_OPTION_LOAD_EXTERNAL_ENTITIES, NULL,
+                         RAPTOR_OPTIONS_GET_NUMERIC(rdf_parser, RAPTOR_OPTION_LOAD_EXTERNAL_ENTITIES));
+  if(rdf_parser->uri_filter)
+    raptor_sax2_set_uri_filter(rss_parser->sax2, rdf_parser->uri_filter,
+                               rdf_parser->uri_filter_user_data);
   
   raptor_sax2_parse_start(rss_parser->sax2, uri);
 
@@ -729,7 +734,9 @@ raptor_rss_end_element_handler(void *user_data,
 
     if(rss_parser->current_block) {
       const raptor_rss_block_field_info *bfi;
+#ifdef RAPTOR_DEBUG
       int handled = 0;
+#endif
       /* in a block, maybe store the CDATA there */
 
       for(bfi = &raptor_rss_block_fields_info[0];
@@ -748,7 +755,9 @@ raptor_rss_end_element_handler(void *user_data,
           return;
         }
         
+#ifdef RAPTOR_DEBUG
         handled = 1;
+#endif
         break;
       }
 
@@ -1063,7 +1072,7 @@ raptor_rss_insert_identifiers(raptor_parser* rdf_parser)
   /* sequence of rss:item */
   for(item = rss_parser->model.items; item; item = item->next) {
     raptor_rss_block *block;
-    raptor_uri* uri;
+    raptor_uri* uri = NULL;
     
     if(!item->fields[RAPTOR_RSS_FIELD_LINK])  {
       if(raptor_rss_insert_rss_link(rdf_parser, item))
@@ -1089,6 +1098,9 @@ raptor_rss_insert_identifiers(raptor_parser* rdf_parser)
       }
     }
 
+    if(!uri)
+      continue;
+
     item->term = raptor_new_term_from_uri(rdf_parser->world, uri);
     raptor_free_uri(uri);
     uri = NULL;
