@@ -26,11 +26,6 @@
 #include <raptor_config.h>
 #endif
 
-#ifdef WIN32
-#include <win32_raptor_config.h>
-#endif
-
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -163,7 +158,7 @@ raptor_rdfxmla_emit_resource_uri(raptor_serializer *serializer,
   RAPTOR_DEBUG2("Emitting resource predicate URI %s\n",
                 raptor_uri_as_string(uri));
 
-  attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 1, sizeof(raptor_qname*));
+  attrs = RAPTOR_CALLOC(raptor_qname**, 1, sizeof(raptor_qname*));
   if(!attrs)
     return 1;
     
@@ -181,7 +176,7 @@ raptor_rdfxmla_emit_resource_uri(raptor_serializer *serializer,
                                                         attr_value);
       
   if(RAPTOR_OPTIONS_GET_NUMERIC(serializer, RAPTOR_OPTION_RELATIVE_URIS))
-    RAPTOR_FREE(cstring, attr_value);
+    RAPTOR_FREE(char*, attr_value);
 
   if(!attrs[0]) {
     RAPTOR_FREE(qnamearray, attrs);
@@ -219,9 +214,7 @@ raptor_rdfxmla_emit_resource(raptor_serializer *serializer,
 {
   int rc;
   
-  RAPTOR_DEBUG5("Emitting resource node %p refcount %d subject %d object %d\n",
-                node, 
-                node->ref_count, node->count_as_subject, node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting resource node", node);
 
   if(node->term->type != RAPTOR_TERM_TYPE_URI)
     return 1;
@@ -229,7 +222,7 @@ raptor_rdfxmla_emit_resource(raptor_serializer *serializer,
   rc = raptor_rdfxmla_emit_resource_uri(serializer, element, 
                                         node->term->value.uri, depth);
   
-  RAPTOR_DEBUG2("Emitted resource node %p\n", node);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitted resource node", node);
 
   return rc;
 }
@@ -257,9 +250,7 @@ raptor_rdfxmla_emit_literal(raptor_serializer *serializer,
   raptor_qname **attrs;
   int attrs_count;
   
-  RAPTOR_DEBUG5("Emitting literal node %p refcount %d subject %d object %d\n",
-                node, 
-                node->ref_count, node->count_as_subject, node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting literal node", node);
 
   if(node->term->type != RAPTOR_TERM_TYPE_LITERAL)
     return 1;
@@ -267,7 +258,7 @@ raptor_rdfxmla_emit_literal(raptor_serializer *serializer,
   if(node->term->value.literal.language || node->term->value.literal.datatype) {
           
     attrs_count = 0;
-    attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 2, sizeof(raptor_qname*));
+    attrs = RAPTOR_CALLOC(raptor_qname**, 2, sizeof(raptor_qname*));
     if(!attrs)
       return 1;
 
@@ -294,7 +285,7 @@ raptor_rdfxmla_emit_literal(raptor_serializer *serializer,
       /* SJS Note: raptor_default_uri_as_string simply returns a
        * pointer to the string. Hope this is also true of alternate
        * uri implementations. */
-      /* RAPTOR_FREE(cstring, datatype_value); */
+      /* RAPTOR_FREE(char*, datatype_value); */
 
     }
 
@@ -306,7 +297,7 @@ raptor_rdfxmla_emit_literal(raptor_serializer *serializer,
   raptor_xml_writer_cdata(xml_writer, node->term->value.literal.string);
   raptor_xml_writer_end_element(xml_writer, element);
 
-  RAPTOR_DEBUG2("Emitted %p\n", node);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitted literal node", node);
   
   return 0;
 
@@ -345,9 +336,7 @@ raptor_rdfxmla_emit_blank(raptor_serializer *serializer,
 {
   raptor_rdfxmla_context* context = (raptor_rdfxmla_context*)serializer->context;
 
-  RAPTOR_DEBUG5("Emitting blank node %p refcount %d subject %d object %d\n",
-                node, 
-                node->ref_count, node->count_as_subject, node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting blank node", node);
 
   if(node->term->type != RAPTOR_TERM_TYPE_BLANK)
     return 1;
@@ -372,7 +361,7 @@ raptor_rdfxmla_emit_blank(raptor_serializer *serializer,
     unsigned char *attr_value = node->term->value.blank.string;
     raptor_qname **attrs;
 
-    attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 1, sizeof(raptor_qname*));
+    attrs = RAPTOR_CALLOC(raptor_qname**, 1, sizeof(raptor_qname*));
     if(!attrs)
       return 1;
 
@@ -388,7 +377,7 @@ raptor_rdfxmla_emit_blank(raptor_serializer *serializer,
 
   raptor_xml_writer_end_element(context->xml_writer, element);
 
-  RAPTOR_DEBUG2("Emitted %p\n", node);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitted blank node", node);
   
   return 0;
 }
@@ -414,10 +403,7 @@ raptor_rdfxmla_emit_subject_list_items(raptor_serializer* serializer,
   int i = 0;
   raptor_uri* base_uri = NULL;
 
-  RAPTOR_DEBUG5("Emitting subject list items for node %p refcount %d subject %d object %d\n", 
-                subject->node,
-                subject->node->ref_count, subject->node->count_as_subject, 
-                subject->node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting subject list items", subject->node);
 
   while(!rv && i < raptor_sequence_size(subject->list_items)) {
 
@@ -500,10 +486,7 @@ raptor_rdfxmla_emit_subject_properties(raptor_serializer* serializer,
   raptor_avltree_iterator* iter = NULL;
   raptor_term* subject_term = subject->node->term;
 
-  RAPTOR_DEBUG5("Emitting subject properties for node %p refcount %d subject %d object %d\n", 
-                subject->node, subject->node->ref_count, 
-                subject->node->count_as_subject,
-                subject->node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting subject properties", subject->node);
 
   /* Emit any rdf:_n properties collected */
   if(raptor_sequence_size(subject->list_items) > 0) {
@@ -663,17 +646,13 @@ raptor_rdfxmla_emit_subject(raptor_serializer *serializer,
                                               context->single_node));
   
 
-  RAPTOR_DEBUG5("Emitting subject node %p refcount %d subject %d object %d\n", 
-                subject->node,
-                subject->node->ref_count, 
-                subject->node->count_as_subject,
-                subject->node->count_as_object);
-
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting subject node", subject->node);
+  
   if(!depth &&
      subject_term->type == RAPTOR_TERM_TYPE_BLANK &&
      subject->node->count_as_subject == 1 &&
      subject->node->count_as_object == 1) {
-    RAPTOR_DEBUG2("Skipping subject node %p\n", subject->node);
+    RAPTOR_DEBUG_ABBREV_NODE("Skipping subject node", subject->node);
     return 0;
   }
   
@@ -712,7 +691,7 @@ raptor_rdfxmla_emit_subject(raptor_serializer *serializer,
     goto oom;
   }
     
-  attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 1, sizeof(raptor_qname*));
+  attrs = RAPTOR_CALLOC(raptor_qname**, 1, sizeof(raptor_qname*));
   if(!attrs)
     goto oom;
     
@@ -724,8 +703,7 @@ raptor_rdfxmla_emit_subject(raptor_serializer *serializer,
     attr_name = (unsigned char*)"about";
     if(context->is_xmp) {
       /* XML rdf:about value is always "" */
-      attr_value = (unsigned char *)RAPTOR_CALLOC(string, 1, 
-                                                  sizeof(unsigned char));
+      attr_value = RAPTOR_CALLOC(unsigned char*, 1, sizeof(unsigned char));
     } else if(RAPTOR_OPTIONS_GET_NUMERIC(serializer,
                                          RAPTOR_OPTION_RELATIVE_URIS))
       attr_value = raptor_uri_to_relative_uri_string(serializer->base_uri,
@@ -753,7 +731,7 @@ raptor_rdfxmla_emit_subject(raptor_serializer *serializer,
                                                           attr_value);
     
     if(subject_term->type != RAPTOR_TERM_TYPE_BLANK)
-      RAPTOR_FREE(cstring, attr_value);
+      RAPTOR_FREE(char*, attr_value);
     
     if(!attrs[0]) {
       RAPTOR_FREE(qnamearray, attrs);
@@ -1270,7 +1248,7 @@ raptor_rdfxmla_ensure_writen_header(raptor_serializer* serializer,
      RAPTOR_OPTIONS_GET_NUMERIC(serializer, RAPTOR_OPTION_WRITE_BASE_URI)) {
     const unsigned char* base_uri_string;
 
-    attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 1, sizeof(raptor_qname*));
+    attrs = RAPTOR_CALLOC(raptor_qname**, 1, sizeof(raptor_qname*));
     if(!attrs)
       goto oom;
 
@@ -1523,7 +1501,8 @@ raptor_rdfxml_xmp_serializer_register_factory(raptor_serializer_factory *factory
 
 static const char* const rdfxmla_names[2] = { "rdfxml-abbrev", NULL};
 
-static const char* const rdfxml_uri_strings[2] = {
+static const char* const rdfxml_uri_strings[3] = {
+  "http://www.w3.org/ns/formats/RDF_XML",
   "http://www.w3.org/TR/rdf-syntax-grammar",
   NULL
 };
