@@ -171,9 +171,7 @@ raptor_turtle_emit_resource(raptor_serializer *serializer,
 
   raptor_qname* qname = NULL;
 
-  RAPTOR_DEBUG5("Emitting resource node %p refcount %d subject %d object %d\n",
-                node, 
-                node->ref_count, node->count_as_subject, node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting resource node", node);
 
   if(node->term->type != RAPTOR_TERM_TYPE_URI)
     return 1;
@@ -194,7 +192,7 @@ raptor_turtle_emit_resource(raptor_serializer *serializer,
     raptor_turtle_writer_reference(turtle_writer, node->term->value.uri);
   }
 
-  RAPTOR_DEBUG2("Emitted %p\n", node);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitted", node);
   
   return 0;
 }
@@ -219,9 +217,7 @@ raptor_turtle_emit_literal(raptor_serializer *serializer,
   raptor_turtle_writer *turtle_writer = context->turtle_writer;
   int rc = 0;
   
-  RAPTOR_DEBUG5("Emitting literal node %p refcount %d subject %d object %d\n",
-                node, 
-                node->ref_count, node->count_as_subject, node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting literal node", node);
 
   if(node->term->type != RAPTOR_TERM_TYPE_LITERAL)
     return 1;
@@ -231,7 +227,7 @@ raptor_turtle_emit_literal(raptor_serializer *serializer,
                                     node->term->value.literal.language, 
                                     node->term->value.literal.datatype);
 
-  RAPTOR_DEBUG2("Emitted %p\n", node);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitted literal node", node);
   
   return rc;
 }
@@ -255,9 +251,7 @@ raptor_turtle_emit_blank(raptor_serializer *serializer,
   raptor_turtle_context* context = (raptor_turtle_context*)serializer->context;
   int rc = 0;
   
-  RAPTOR_DEBUG5("Emitting blank node %p refcount %d subject %d object %d\n",
-                node, 
-                node->ref_count, node->count_as_subject, node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting blank node", node);
   
   if(node->term->type != RAPTOR_TERM_TYPE_BLANK)
     return 1;
@@ -281,7 +275,7 @@ raptor_turtle_emit_blank(raptor_serializer *serializer,
                                  node->term->value.blank.string_len);
   }
 
-  RAPTOR_DEBUG2("Emitted %p\n", node);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitted blank node", node);
   
   return rc;
 }
@@ -305,10 +299,7 @@ raptor_turtle_emit_subject_list_items(raptor_serializer* serializer,
   int rv = 0;
   int i = 0;
 
-  RAPTOR_DEBUG5("Emitting subject list items for node %p refcount %d subject %d object %d\n", 
-                subject->node,
-                subject->node->ref_count, subject->node->count_as_subject, 
-                subject->node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting subject list items", subject->node);
 
   while(!rv && i < raptor_sequence_size(subject->list_items)) {
     raptor_abbrev_node* object;
@@ -367,10 +358,7 @@ raptor_turtle_emit_subject_collection_items(raptor_serializer* serializer,
   int i;
   int is_new_subject = 0;
 
-  RAPTOR_DEBUG5("Emitting subject collection items for node %p refcount %d subject %d object %d\n", 
-                subject->node,
-                subject->node->ref_count, subject->node->count_as_subject, 
-                subject->node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting subject collection items", subject->node);
 
   /* if just saw a new subject (is_new_subject is true) then there is no need
    * to advance the iterator - it was just reset
@@ -500,10 +488,7 @@ raptor_turtle_emit_subject_properties(raptor_serializer* serializer,
   raptor_avltree_iterator* iter = NULL;
   int i;
 
-  RAPTOR_DEBUG5("Emitting subject properties for node %p refcount %d subject %d object %d\n", 
-                subject->node, subject->node->ref_count, 
-                subject->node->count_as_subject,
-                subject->node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting subject properties", subject->node);
 
   /* Emit any rdf:_n properties collected */
   if(raptor_sequence_size(subject->list_items) > 0)
@@ -526,7 +511,7 @@ raptor_turtle_emit_subject_properties(raptor_serializer* serializer,
     if(!(last_predicate && raptor_abbrev_node_equals(predicate, last_predicate))) {
       /* no object list abbreviation possible, terminate last object */
       if(last_predicate) {
-        raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)" ;");
+        raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)" ;", 2);
         raptor_turtle_writer_newline(turtle_writer);
       }
 
@@ -535,18 +520,18 @@ raptor_turtle_emit_subject_properties(raptor_serializer* serializer,
                                                   10);
 
       if(raptor_abbrev_node_equals(predicate, context->rdf_type))
-        raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)"a");
+        raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)"a", 1);
       else if(qname)
         raptor_turtle_writer_qname(turtle_writer, qname);
       else
         raptor_turtle_writer_reference(turtle_writer, predicate->term->value.uri);
 
-      raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)" ");
+      raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)" ", 1);
     
       if(qname)
         raptor_free_qname(qname);
     } else
-      raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)", ");
+      raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)", ", 2);
 
 
     switch(object->term->type) {
@@ -606,22 +591,18 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
   
   if(!raptor_abbrev_subject_valid(subject)) return 0;
 
-  RAPTOR_DEBUG5("Emitting subject node %p refcount %d subject %d object %d\n", 
-                subject->node,
-                subject->node->ref_count, 
-                subject->node->count_as_subject,
-                subject->node->count_as_object);
+  RAPTOR_DEBUG_ABBREV_NODE("Emitting subject node", subject->node);
 
   if(!depth &&
      subject->node->term->type == RAPTOR_TERM_TYPE_BLANK &&
      subject->node->count_as_subject == 1 &&
      subject->node->count_as_object == 1) {
-    RAPTOR_DEBUG2("Skipping subject node %p\n", subject->node);
+    RAPTOR_DEBUG_ABBREV_NODE("Skipping subject node - subj & obj count 1", subject->node);
     return 0;
   }
   
   if(raptor_avltree_size(subject->properties) == 0) {
-    RAPTOR_DEBUG2("Skipping subject node %p\n", subject->node);
+    RAPTOR_DEBUG_ABBREV_NODE("Skipping subject node - no props", subject->node);
     return 0;
   }
 
@@ -666,27 +647,21 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
         subject->node->count_as_object == 0) && depth > 1) { 
       blank = 1;
     } else if(subject->node->count_as_object == 0) {
-      raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)"[]");
+      raptor_turtle_writer_raw_counted(turtle_writer,
+                                       (const unsigned char*)"[]", 2);
       blank = 0;
     } else if(!collection && subject->node->count_as_object > 1) {
       /* Referred to (used as an object), so needs a nodeID */
-      const unsigned char* genid = subject->node->term->value.blank.string;
-      size_t len = strlen((const char*)genid);
-      unsigned char* subject_str;
-      subject_str= RAPTOR_MALLOC(unsigned char*, len + 3);
-      if(!subject_str)
-        return 1;
-
-      subject_str[0]='_';
-      subject_str[1]=':';
-      memcpy(&subject_str[2], genid, len + 1);
-      raptor_turtle_writer_raw(turtle_writer, subject_str);
-      RAPTOR_FREE(char*, subject_str);
+      raptor_turtle_writer_raw_counted(turtle_writer,
+                                       (const unsigned char*)"_:", 2);
+      raptor_turtle_writer_raw_counted(turtle_writer,
+                                       subject->node->term->value.blank.string,
+                                       subject->node->term->value.blank.string_len);
     }
   } 
 
   if(collection) {
-    raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)"(");
+    raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)"(", 1);
     
     raptor_turtle_writer_increase_indent(turtle_writer);
     
@@ -695,11 +670,11 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
     raptor_turtle_writer_decrease_indent(turtle_writer);
     raptor_turtle_writer_newline(turtle_writer);
     
-    raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)")");
+    raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)")", 1);
 
   } else {
     if(blank && depth > 1)
-      raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)"[");
+      raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)"[", 1);
     
     raptor_turtle_writer_increase_indent(turtle_writer);
     raptor_turtle_writer_newline(turtle_writer);
@@ -710,7 +685,7 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
     
     if(blank && depth > 1) {
       raptor_turtle_writer_newline(turtle_writer);
-      raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)"]");
+      raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)"]", 1);
     }
   }
 
@@ -720,7 +695,7 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
      * (the "." will be parsed as part of the literal and statement
      * left unterminated) 
      */
-    raptor_turtle_writer_raw(turtle_writer, (const unsigned char*)" .");
+    raptor_turtle_writer_raw_counted(turtle_writer, (const unsigned char*)" .", 2);
     raptor_turtle_writer_newline(turtle_writer);
     raptor_turtle_writer_newline(turtle_writer);
   }
@@ -1036,7 +1011,7 @@ raptor_turtle_ensure_writen_header(raptor_serializer* serializer,
     raptor_namespace_stack_start_namespace(context->nstack, ns, 0);
   }
   
-  raptor_turtle_writer_raw(context->turtle_writer, (const unsigned char*)"\n");
+  raptor_turtle_writer_newline(context->turtle_writer);
 
   context->written_header = 1;
 }
